# Introduction

```{include} ../../README.md
:relative-docs: ../../
:relative-images: ../../
# Optional to include only part of README:
#:start-after: <!-- intro-start -->
#:end-before:  <!-- intro-end -->
